<?php
/*
Plugin Name: Navigation Block
Plugin URI: http://www.interconnectit.com
Description: Custom Navigation block.
Author: James R Whitehead
Version: 1.4
Author URI: http://www.interconnectit.com
*/

/* Revision 

1.4	-	Added Links option to the navigation.
		Also added an option to categorise links or show flat.
		
1.3	-	Fixed an issue due to change from wp 2.2 to 2.2.1. 
		There was an extra arg passed to the widget_output 
		function under 2.2.1 that was not there under 2.2.
		This resulted in the expected arg being the label 
		rather than the settings array. Fixed this by grabbing 
		all args to a single var, defined or not.
		
1.2	-	Added Archives.
1.1	-	Added Control options.
1.0	-	Initial release.
*/

//delete_option("icit-navigation-widget-options");
$icit_navigation_widget = new icit_navigation_widget();
add_action('widgets_init', array($icit_navigation_widget,'register'));

class icit_navigation_widget {
	function icit_navigation_widget() {
		$this->config = array (
		"number" => 1,
		"title" => "ICIT Navigation",
		"label" => "icit-navigation-widget",
		"settings" => array(
			array("name" => "title",	"default-value" => "",			"type" => "text",		"description" => "Global title"),
			array("name" => "nav_title","default-value" => "Navigate",	"type" => "text",		"description" => "title"),
			array("name" => "cat_title","default-value" => "Categories","type" => "text",		"description" => "Category title"),
			array("name" => "arc_title","default-value" => "Archive",	"type" => "text",		"description" => "Archive title"),
			array("name" => "lnk_title","default-value" => "Links",		"type" => "text",		"description" => "Links title"),
			array("name" => "rss",		"default-value" => true,		"type" => "checkbox",	"description" => "Show RSS link"),
			array("name" => "category",	"default-value" => true,		"type" => "checkbox",	"description" => "Show Categories"),
			array("name" => "archive",	"default-value" => true,		"type" => "checkbox",	"description" => "Show Archives"),
			array("name" => "links",	"default-value" => true,		"type" => "checkbox",	"description" => "Show Links"),
			array("name" => "links_cat","default-value" => false,		"type" => "checkbox",	"description" => "Categorise Links")
		)
		);
	}		
	// Widgets visitor facing element.
	function widget_output($args,$label = 1) {
		$params = func_get_args();
		foreach ($params as $param) if (is_array($param)) extract($param,EXTR_SKIP);
		// Output.
		echo $before_widget; 
		if ($title) echo $before_title.$title.$after_title;	?>
		<?php 
			if ($rss) { ?>
				<a href="<?php bloginfo('rss2_url');?>" class="rss-link">
					<img src="<?php bloginfo('template_directory');?>/style/rssicon.png" alt="RSS" />
				</a><?php
			} 
			echo ($nav_title != "" ? "<h3>$nav_title</h3>" : "<h3>Navigate</h3>" );
			global $post;
			$exclude = get_option("page_on_front");
			if ((is_home() and get_option("show_on_front") != "page") or ((get_option("page_on_front") == "{$post->ID}") and get_option("show_on_front") == "page")) {
				$highlight = " current_page_item";
			}?>
			<ul class="pages-list">
				<li class="page_item <?php echo $highlight; ?>"><a href="<?php echo get_settings('home'); ?>">Home</a></li>
				<?php wp_list_pages("sort_column=menu_order&title_li=&depth=3");?>
			</ul><?php
			if ($category) { 
				echo ($cat_title != "" ? "<h3>$cat_title</h3>" : "" ); ?>
				<ul class="categories-list"><?php
					wp_list_categories("children=1&hierarchical=1&use_desc_for_title=0&title_li=");?>
				</ul><?php
			}
			if ($archive) {
				echo ($arc_title != "" ? "<h3>$arc_title</h3>" : "" ); ?>
				<ul class="categories-list">
					<?php  wp_get_archives("type=monthly&limit=12&format=html&before=&after=");?>
				</ul><?php
			}
			if ($links) {
				$settings = array(
					"orderby" => "name",
					"order" => "ASC", "limit" => -1,
					"category" => "",
					"category_name" => "",
					"hide_invisible" => 1,
					"show_updated" => 0,
					"echo" => 1,
					"categorize" => $links_cat,
					"title_li" => "",
					"title_before" => "<h3>",
					"title_after" => "</h3>",
					"category_orderby" => "name",
					"category_order" => "ASC",
					"class" => "linkcat",
					"category_before" => "<li id=\"%id\" class=\"%class\">",
					"category_after" => "</li>");
				echo ($lnk_title != "" ? "<h3>$lnk_title</h3>" : "" ); ?>
				<ul <?php echo ($settings["categorize"] ? " class=\"categories-list\"" : "class=\"pages-list\"");?>>
					<?php wp_list_bookmarks($settings);?>
				</ul><?php 
			}
		echo $after_widget;
//		trace($post);
	}
	
/****************************************** There should be no need to edit below this point. *********************************/

	function get_settings() {
		// Get the existing settings back from the options.
		$this->original = $this->settings = get_option("{$this->config["label"]}-options");
		// Check to see if there was a change to the number of widgets and update.
		if ($_POST["{$this->config["label"]}-submit"] != "") {
			$this->settings["number"] = strip_tags(stripslashes($_POST["{$this->config["label"]}-count"]));
		}
		// Check to see if the number of widgets is within range.
		if ($this->settings["number"] < 1) $this->settings["number"] = 1;
		if ($this->settings["number"] > $this->config["number"]) $this->settings["number"] = $this->config["number"];
		
		for ($i = 1; $i <= $this->settings["number"]; $i++) {
			if ($this->settings[$i]["defaults_set"] != true) $setdefaults = $this->settings[$i]["defaults_set"] = true;
		if (count($this->config["settings"]) >= 1 && is_array($this->config["settings"]))
			foreach ($this->config["settings"] as $item) {
				if (is_array($item))  {
					$label = "{$this->config["label"]}-$i-{$item["name"]}";
					$value = $this->settings[$i]["{$item["name"]}"];
					$default = $item["default-value"];
					if ($setdefaults) $this->settings[$i]["{$item["name"]}"] = $default;
					if ($_POST["{$this->config["label"]}-$i-submitted"]) {
						$this->settings[$i]["{$item["name"]}"] = strip_tags(stripslashes($_POST[$label]));
						// Call the validator if one is set. The validator function should return True is all is good else I will set the value to the default.
						if (method_exists($this,$item["validator"])) {
							if(!call_user_func(array($this,$item["validator"]),$this->settings[$i]["{$item["name"]}"])) $this->settings[$i]["{$item["name"]}"] = $item["default-value"];;
						} elseif (function_exists($item["validator"])) {
							if(!call_user_func($item["validator"],$this->settings[$i]["{$item["name"]}"])) $this->settings[$i]["{$item["name"]}"] = $item["default-value"];
						}
					}
				}
			}
		}
		// Save the options if they have chaanged.
		if ($this->original != $this->settings) $this->save_settings();
		// Look for and execute a function called additional_filters;
		if (method_exists($this,"additional_filters")) call_user_func(array($this,"additional_filters"));
	}

	function save_settings() {
		add_option("{$this->config["label"]}-options",'',"{$this->config["title"]}",'yes');
		update_option("{$this->config["label"]}-options", $this->settings);
	}

	// The setting interface
	function widget_control($i = 1) {
		foreach ($this->config["settings"] as $item) {
			if (is_array($item))  {
				$label = "{$this->config["label"]}-$i-{$item["name"]}";
				$value = $this->settings[$i]["{$item["name"]}"];
				$description = $item["description"];
				$type = $item["type"];
				echo "<div style=\"text-align: left; clear:left; margin-bottom: 10px;\">
				<label for=\"$label\"style=\"width: 130px; margin-right: 10px; float: left;\" >$description</label>";
				switch ($type){
					case "text" :
						echo "<input id=\"$label\" type=\"$type\" name=\"$label\" value=\"$value\" />";
					break;
					case "checkbox" :
						echo "<input id=\"$label\" type=\"$type\" name=\"$label\" ".($value != "" ? "checked=\"checked\"" : "")." value=\"1\" />";
					break;
					case "select" :
						// First check that the option-list is an array and set the options to that if it is. 
						// Else I presume its a call to a function that outputs and array so try and execute it.
						if (is_array($item["option-list"])) {
							$optionlist = $item["option-list"];
						} elseif (method_exists($this,$item["option-list"])) {
							$optionlist = call_user_func(array($this,$item["option-list"]));
						} 
						// Check that the previous section outputted an array and that the array has content.
						if (!is_array($optionlist) && !count($optionlist) >= 1) {
							echo "<span style=\"color: red;\">Error: missing or corrupt option-list array.</span><br/>";
							break;
						}
						echo "<select id=\"$label\" name=\"$label\" style=\"width:163px\"/>";
							foreach (array_keys($optionlist) as $option) {
								echo "<option value=\"{$optionlist[$option]}\" ".($value == $optionlist[$option] ? "selected=\"selected\"" : "").">$option</option>";
							}
						echo "</select>";
					break;
				}
				echo "<hr style=\"visibility:hidden; clear:both;\"/>
				</div>";
			}
		}
		?>
		<input type="hidden" value="1" name="<?php echo "{$this->config["label"]}-$i-submitted";?>" id="<?php echo $label;?>-submitted"/><?php
	}
	
	// The "how many widgets do you want?" interface.
	function page() {?>
		<div class="wrap">
			<form method="POST">
				<h2><?php echo $this->config["title"]; ?></h2>
				<p><label for="<?php echo $this->config["label"];?>-count" style="line-height: 30px;">How many <?php echo $this->config["title"]; ?> widgets would you like?</label>
				<select id="<?php echo $this->config["label"];?>-count" name="<?php echo $this->config["label"];?>-count" value="<?php echo $this->settings["number"]; ?>">
					<?php for ( $i = 1; $i <= $this->config["number"]; ++$i ) echo "<option value='$i' ".($this->settings["number"] == $i ? "selected='selected'" : '').">$i</option>"; ?>
				</select>
				<span class="submit"><input type="submit" name="<?php echo $this->config["label"];?>-submit" id="<?php echo $this->config["label"];?>-submit" value="Save" /></span></p>
			</form>
		</div><?php
	}

	function register() {
		// Check to see if widgeting is available
		if (!function_exists('register_sidebar_widget')) return;
		// Get the settings from the DB.
		$this->get_settings();
		// Add a widget and controller for the number stated.
		for ($i = 1; $i <= $this->settings['number']; $i++) {
			if ($this->config['number'] == 1) {
				$name = array("{$this->config["title"]}", "widgets", $i);
			} else {
				$name = array("{$this->config["title"]} %s", "widgets", $i);
			}
			register_sidebar_widget($name, array($this,'widget_output'), "{$this->config["label"]}",$this->settings[$i]);
			if (count($this->config["settings"]) >= 1) register_widget_control($name, array($this,'widget_control'),310,(count($this->config["settings"])*40)+10,$i);
		}
		// Add the interface to choose how many widgets you want available.
		if ($this->config["number"] > 1) add_action('sidebar_admin_page', array($this,'page'));
	}
}?>
